@@ -18,9 +18,9 @@
 #' 
 #' @section II. Conversion: 
 #' \tabular{ll}{
-#'  \code{\link{boxSpatial}} \tab convert boxes to a \code{\link{SpatialPolygonsDataFrame}}\cr
-#'  \code{\link{faceSpatial}} \tab convert faces to a \code{\link{SpatialLinesDataFrame}} \cr
-#'  \code{\link{boundarySpatial}} \tab convert boundary to a single-row \code{\link{SpatialPolygonsDataFrame}}\cr
+#'  \code{\link{boxSpatial}} \tab convert boxes to a \code{\link[sp:SpatialPolygonsDataFrame]{SpatialPolygonsDataFrame}}\cr
+#'  \code{\link{faceSpatial}} \tab convert faces to a \code{\link[sp:SpatialLinesDataFrame]{SpatialLinesDataFrame}} \cr
+#'  \code{\link{boundarySpatial}} \tab convert boundary to a single-row \code{\link[sp:SpatialPolygonsDataFrame]{SpatialPolygonsDataFrame}}\cr
 #'  \code{\link{nodeSpatial}} \tab obtain all vertices as points \cr
 #'  \code{\link{pointSpatial}} \tab obtain all instances of vertices as points \cr
 #' }
@@ -35,8 +35,7 @@
 #' @importFrom rlang .data
 #' @importFrom sp spDistsN1 Line Lines SpatialLines CRS SpatialLinesDataFrame
 #' @name rbgm-package
-#' @docType package
-NULL
+"_PACKAGE"
 
 
 
